@@ -21,7 +21,7 @@ class Pipelines(BitbucketCloudBase):
 
         1. Latest revision of a branch (specify ``branch``)
         2. Specific commit on a branch (additionally specify ``commit``)
-        3. Specific pipeline (additionally specify ``pattern``)
+        3. Specific pipeline (additionally specify ``pattern``. ``commit`` is optional here)
 
         Variables has to be a list of dictionaries:
 
@@ -48,8 +48,6 @@ class Pipelines(BitbucketCloudBase):
                 "hash": commit,
             }
         if pattern is not None:
-            if commit is None:
-                raise ValueError("Missing argument [commit].")
             data["target"]["selector"] = {
                 "type": "custom",
                 "pattern": pattern,
